# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataTypeResponse(Model):
    """DataTypeResponse.

    :param data_type_id:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_id: int
    :param data_type_code:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_code: str
    :param data_type_info:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_info: str
    """

    _attribute_map = {
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
        'data_type_code': {'key': 'dataTypeCode', 'type': 'str'},
        'data_type_info': {'key': 'dataTypeInfo', 'type': 'str'},
    }

    def __init__(self, data_type_id=None, data_type_code=None, data_type_info=None):
        super(DataTypeResponse, self).__init__()
        self.data_type_id = data_type_id
        self.data_type_code = data_type_code
        self.data_type_info = data_type_info
