# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitChild(Model):
    """UnitChild.

    :param unit_id: The unit identifier
    :type unit_id: int
    :param unit_code: The unit code
    :type unit_code: str
    :param unit_info: The unit info
    :type unit_info: str
    """

    _attribute_map = {
        'unit_id': {'key': 'unitId', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'unit_info': {'key': 'unitInfo', 'type': 'str'},
    }

    def __init__(self, unit_id=None, unit_code=None, unit_info=None):
        super(UnitChild, self).__init__()
        self.unit_id = unit_id
        self.unit_code = unit_code
        self.unit_info = unit_info
