# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCost(Model):
    """MeterCost.

    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param total_cost: Total cost
    :type total_cost: float
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, meter=None, place=None, total_cost=None, cost_unit=None):
        super(MeterCost, self).__init__()
        self.meter = meter
        self.place = place
        self.total_cost = total_cost
        self.cost_unit = cost_unit
