# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyEditRequest(Model):
    """ApiKeyEditRequest.

    :param api_key_name: The name of the API key <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 60 characters</span>
    :type api_key_name: str
    :param api_key_description: A description for the API key <span
     class='property-internal'>Required</span>
    :type api_key_description: str
    """

    _validation = {
        'api_key_name': {'required': True, 'max_length': 60, 'min_length': 0},
        'api_key_description': {'required': True},
    }

    _attribute_map = {
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
    }

    def __init__(self, api_key_name, api_key_description):
        super(ApiKeyEditRequest, self).__init__()
        self.api_key_name = api_key_name
        self.api_key_description = api_key_description
