# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillUsage(Model):
    """BillUsage.

    :param manually_entered: Number of bills that are manually entered.
    :type manually_entered: int
    :param imported: Number of bills that are imported.
    :type imported: int
    :param chargeback: Number of bills that are chargeback.
    :type chargeback: int
    :param accrual: Number of bills that have accrued.
    :type accrual: int
    """

    _attribute_map = {
        'manually_entered': {'key': 'manuallyEntered', 'type': 'int'},
        'imported': {'key': 'imported', 'type': 'int'},
        'chargeback': {'key': 'chargeback', 'type': 'int'},
        'accrual': {'key': 'accrual', 'type': 'int'},
    }

    def __init__(self, manually_entered=None, imported=None, chargeback=None, accrual=None):
        super(BillUsage, self).__init__()
        self.manually_entered = manually_entered
        self.imported = imported
        self.chargeback = chargeback
        self.accrual = accrual
