# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DestinationAccountMeterChild(Model):
    """DestinationAccountMeterChild.

    :param account_meter_id: The AccountMeter identifier <span
     class='property-internal'>Required (defined)</span>
    :type account_meter_id: int
    :param meter_id: The Meter identifier for this AccountMeter <span
     class='property-internal'>Required (defined)</span>
    :type meter_id: int
    :param meter_code: The code of the Meter for this AccountMeter <span
     class='property-internal'>Required (defined)</span>
    :type meter_code: str
    :param meter_info: The info of the Meter for this AccountMeter <span
     class='property-internal'>Required (defined)</span>
    :type meter_info: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, account_meter_id=None, meter_id=None, meter_code=None, meter_info=None, commodity=None):
        super(DestinationAccountMeterChild, self).__init__()
        self.account_meter_id = account_meter_id
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.commodity = commodity
