# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestGHGYearlyResponseGHGScope(Model):
    """MeterDigestGHGYearlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param ghg_scope_type_code: GHG scope type code
    :type ghg_scope_type_code: str
    :param ghg_scope_type_info: GHG scope type code
    :type ghg_scope_type_info: str
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'ghg_scope_type_code': {'key': 'ghgScopeTypeCode', 'type': 'str'},
        'ghg_scope_type_info': {'key': 'ghgScopeTypeInfo', 'type': 'str'},
    }

    def __init__(self, ghg_scope_id=None, ghg_scope_code=None, ghg_scope_info=None, ghg_scope_type_code=None, ghg_scope_type_info=None):
        super(MeterDigestGHGYearlyResponseGHGScope, self).__init__()
        self.ghg_scope_id = ghg_scope_id
        self.ghg_scope_code = ghg_scope_code
        self.ghg_scope_info = ghg_scope_info
        self.ghg_scope_type_code = ghg_scope_type_code
        self.ghg_scope_type_info = ghg_scope_type_info
