# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardCreate(Model):
    """DashboardCreate.

    :param dashboard_info: The Dashboard Title <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type dashboard_info: str
    :param description: The dashboard description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type description: str
    :param type: The dashboard type <span class='property-internal'>One of
     User, Map </span>
    :type type: str
    :param public: Flag to indicate if the dashboard is public
    :type public: bool
    """

    _validation = {
        'dashboard_info': {'required': True, 'max_length': 255, 'min_length': 0},
        'description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'dashboard_info': {'key': 'dashboardInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'public': {'key': 'public', 'type': 'bool'},
    }

    def __init__(self, dashboard_info, description=None, type=None, public=None):
        super(DashboardCreate, self).__init__()
        self.dashboard_info = dashboard_info
        self.description = description
        self.type = type
        self.public = public
