# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LatestBenchmarkValue(Model):
    """LatestBenchmarkValue.

    :param benchmark_value:
    :type benchmark_value: ~energycap.sdk.models.BenchmarkValue
    :param benchmark_indicator: Indicator for which benchmark factor
    :type benchmark_indicator: int
    :param benchmark_info: benchmark info
    :type benchmark_info: str
    :param benchmark_category:
    :type benchmark_category: ~energycap.sdk.models.BenchmarkCategoryResponse
    """

    _attribute_map = {
        'benchmark_value': {'key': 'benchmarkValue', 'type': 'BenchmarkValue'},
        'benchmark_indicator': {'key': 'benchmarkIndicator', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
        'benchmark_category': {'key': 'benchmarkCategory', 'type': 'BenchmarkCategoryResponse'},
    }

    def __init__(self, benchmark_value=None, benchmark_indicator=None, benchmark_info=None, benchmark_category=None):
        super(LatestBenchmarkValue, self).__init__()
        self.benchmark_value = benchmark_value
        self.benchmark_indicator = benchmark_indicator
        self.benchmark_info = benchmark_info
        self.benchmark_category = benchmark_category
