# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionExportHold(Model):
    """ListActionExportHold.

    :param export_hold:  <span class='property-internal'>Required
     (defined)</span>
    :type export_hold: bool
    """

    _attribute_map = {
        'export_hold': {'key': 'exportHold', 'type': 'bool'},
    }

    def __init__(self, export_hold=None):
        super(ListActionExportHold, self).__init__()
        self.export_hold = export_hold
