# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollupUnitUpdate(Model):
    """RollupUnitUpdate.

    :param common_rollups:  <span class='property-internal'>Required
     (defined)</span>
    :type common_rollups:
     list[~energycap.sdk.models.RollupUnitUpdateCommonUnit]
    :param global_rollup_unit_id:  <span class='property-internal'>Required
     (defined)</span>
    :type global_rollup_unit_id: int
    """

    _attribute_map = {
        'common_rollups': {'key': 'commonRollups', 'type': '[RollupUnitUpdateCommonUnit]'},
        'global_rollup_unit_id': {'key': 'globalRollupUnitId', 'type': 'int'},
    }

    def __init__(self, common_rollups=None, global_rollup_unit_id=None):
        super(RollupUnitUpdate, self).__init__()
        self.common_rollups = common_rollups
        self.global_rollup_unit_id = global_rollup_unit_id
